Module theme

Module theme 

Theme trait and core types

Structs

ThemeBundle
A theme bundle containing both light and dark variants

Enums

ColorScheme
Color scheme variant

Traits

Theme
The main theme trait that all themes must implement