Theme trait and core types
Structs
- Theme
Bundle - A theme bundle containing both light and dark variants
Enums
- Color
Scheme - Color scheme variant
Traits
- Theme
- The main theme trait that all themes must implement
Theme trait and core types